/*
 * Copyright (C) 2006-2014 Andre Noll <maan@tuebingen.mpg.de>
 *
 * Licensed under the GPL v2. For licencing details see COPYING.
 */

/** \file fd.h exported symbols from fd.c */

int write_all(int fd, const char *buf, size_t len);
__printf_2_3 int write_va_buffer(int fd, const char *fmt, ...);
int file_exists(const char *);
int para_select(int n, fd_set *readfds, fd_set *writefds,
		struct timeval *timeout_tv);
__must_check int mark_fd_nonblocking(int fd);
__must_check int mark_fd_blocking(int fd);
void para_fd_set(int fd, fd_set *fds, int *max_fileno);
__must_check int para_fgets(char *line, int size, FILE *f);
int para_mmap(size_t length, int prot, int flags, int fd, off_t offset,
		void *map);
int para_open(const char *path, int flags, mode_t mode);
int para_mkdir(const char *path, mode_t mode);
int para_chdir(const char *path);
int mmap_full_file(const char *filename, int open_mode, void **map,
	size_t *size, int *fd_ptr);
int para_munmap(void *start, size_t length);
int write_ok(int fd);
void valid_fd_012(void);
int readv_nonblock(int fd, struct iovec *iov, int iovcnt, fd_set *rfds,
		size_t *num_bytes);
int read_nonblock(int fd, void *buf, size_t sz, fd_set *rfds, size_t *num_bytes);
int read_pattern(int fd, const char *pattern, size_t bufsize, fd_set *rfds);
int xwrite(int fd, const char *buf, size_t len);
int xwritev(int fd, struct iovec *iov, int iovcnt);
int for_each_file_in_dir(const char *dirname,
		int (*func)(const char *, void *), void *private_data);
/**
 * Write a \p NULL-terminated buffer.
 *
 * \param fd The file descriptor.
 * \param buf The null-terminated buffer to be send.
 *
 * This is equivalent to write_all(fd, buf, strlen(buf)).
 *
 * \return Standard.
 */
_static_inline_ int write_buffer(int fd, const char *buf)
{
	return write_all(fd, buf, strlen(buf));
}
