/*
 * Copyright (C) 2006-2014 Andre Noll <maan@tuebingen.mpg.de>
 *
 * Licensed under the GPL v2. For licencing details see COPYING.
 */

/** \file user_list.h exported functions from user_list.c */

/**
 * permission flags that can be set individually for any server command
 *
 * - AFS_READ: read-only command of the audio file selector
 * - AFS_WRITE: command changes state of the audio file selector
 * - VSS_READ: command reads information about the current audio stream
 * - VSS_WRITE: command changes the current audio stream
 */
enum {AFS_READ = 1, AFS_WRITE = 2, VSS_READ = 4, VSS_WRITE = 8};

/**
 * data needed to authenticate the user
 */
struct user {
	/** The position of this user in the list of users. */
	struct list_head node;
	/** The username. */
	char *name;
	/** The public key. */
	struct asymmetric_key *pubkey;
	/** The privileges of this user. */
	unsigned int perms;
};

void init_user_list(char *user_list_file);
struct user *lookup_user(const char *name);
